==> gbsite-1.0.0.tar.gz: gbsite/templates/gb/gb_contactpage.php <==
<form method="post" action="/about/contactsend.php">
<input type="hidden" name="feedback_id" value="<? echo $feedback_id ?>">
<table cellspacing="0" cellpadding="2" border="0" width="100%">
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2" color="<? $color_1 ?>"><b>Address:</b></font></td>
</tr>
<tr>
<td colspan="3">
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>">               
Great Bridge, LLC<br> 
253 Monticello Avenue<br> 
Norfolk, VA 23510<br>
Phone: (757) 233-5500<br>
Fax: (757) 233-5555<br>
<p><br>
</font>
</td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2" color="<? $color_1 ?>"><b>Company Contact:</b></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">Your E-mail Address:</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="15" height="1"></td>
<td width="100%"><input type="text" name="email" maxlength="100"></td>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">Send To:</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="15" height="1"></td>
<td width="100%">
	<select name="cat_id">
		<option value="">- Choose Recipient -
		<? 
		while(list($key,$value) = @each($data)) {
		echo "<option value=$key>$value\n";
		}
		?>
	</select>
</td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">Comments:</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="15" height="1"></td>
<td width="100%"><textarea name="comment" cols="50" rows="5" wrap="virtual"></textarea></td>
</tr>
<tr>
<td colspan="3" align="center"><input type="submit" value="Send"></td>
</tr>
</form>
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/gb/gb_contactpage.php <==
<form method="post" action="/about/contactsend.php">
<input type="hidden" name="feedback_id" value="<? echo $feedback_id ?>">
<table cellspacing="0" cellpadding="2" border="0" width="100%">
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2" color="<? $color_1 ?>"><b>Address:</b></font></td>
</tr>
<tr>
<td colspan="3">
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>">               
Great Bridge, LLC<br> 
253 Monticello Avenue<br> 
Norfolk, VA 23510<br>
Phone: (757) 233-5500<br>
Fax: (757) 233-5555<br><br>
<a href="/about/map.php">Driving Directions</a><br>
<br><br>
</font>
</td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2" color="<? $color_1 ?>"><b>Company Contact:</b></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">Your E-mail Address:</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="15" height="1"></td>
<td width="100%"><input type="text" name="email" maxlength="100"></td>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">Send To:</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="15" height="1"></td>
<td width="100%">
	<select name="cat_id">
		<option value="">- Choose Recipient -
		<? 
		while(list($key,$value) = @each($data)) {
		echo "<option value=$key>$value\n";
		}
		?>
	</select>
</td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">Comments:</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="15" height="1"></td>
<td width="100%"><textarea name="comment" cols="40" rows="5" wrap="virtual"></textarea></td>
</tr>
<tr>
<td colspan="3" align="center"><input type="submit" value="Send"></td>
</tr>
</form>
</table>
